# -*- coding: utf-8 -*-
"""
    ==================
    SQLAlchemy-Wrapper
    ==================

    A framework-independent wrapper for SQLAlchemy that makes it really easy
    to use.

    :copyright: © 2012-2015 by `Juan Pablo Scaletti <http://jpscaletti.com>`_.
    :license: MIT, see LICENSE for more details.

"""
from .main import SQLAlchemy, BaseQuery  # noqa
from .paginator import Paginator  # noqa


__version__ = '1.3.1'
